@@ -3,7 +3,8 @@ from re import RegexFlag
 from typing import List, Optional
 
 from build_pymeos_functions_modifiers import period_shift_tscale_modifier, cstring2text_modifier, text2cstring_modifier, \
-    timestampset_make_modifier, gserialized_from_lwgeom_modifier, tpointseq_make_coords_modifier
+    timestampset_make_modifier, gserialized_from_lwgeom_modifier, tpointseq_make_coords_modifier, \
+    temporal_from_wkb_modifier
 from objects import conversion_map, Conversion
 
 
@@ -109,6 +110,7 @@ function_modifiers = {
     'timestampset_make': timestampset_make_modifier,
     'gserialized_from_lwgeom': gserialized_from_lwgeom_modifier,
     'tpointseq_make_coords': tpointseq_make_coords_modifier,
+    'temporal_from_wkb': temporal_from_wkb_modifier,
 }
 
 # List of result function parameters in tuples of (function, parameter)
@@ -134,6 +136,7 @@ output_parameters = {
 # List of nullable function parameters in tuples of (function, parameter)
 nullable_parameters = {
     ('temporal_as_mfjson', 'srs'),
+    ('gserialized_as_geojson', 'srs'),
     ('period_shift_tscale', 'duration'),
     ('period_shift_tscale', 'start'),
     ('period_shift_tscale', 'start'),
